package org.netkernel.layer0.meta;

import org.netkernel.urii.IIdentifier;
import org.netkernel.urii.ISpace;

/** Logical Endpoints are discrete elements exposed to the containing address-space that a given
 * physical endpoint may implement. The object is the set of logical endpoints exposed by a physical
 * endpoint.
 * @author tab
 */
public interface ILogicalEndpoints
{
	/** Return the number of logical endpoints
	 * @return
	 */
	int size();
	
	/** Return the identifier of the logical endpoint
	 * @param aIndex
	 * @return
	 */
	IIdentifier getIdentifier(int aIndex);
	
	/** Return true if the endpoint is logically delegated from another space
	 * @param aIndex
	 * @return
	 */
	boolean isDelegated(int aIndex);
	
	/** Return the address-space which the endpoint is delegated from if any
	 * @param aIndex
	 * @return
	 */
	ISpace getDelegatedSpace(int aIndex);
}
